@@ -48,13 +48,13 @@ def usage
   STDERR.printf("%s: test cases of the remote database API\n", $progname)
   STDERR.printf("\n")
   STDERR.printf("usage:\n")
-  STDERR.printf("  %s write [-port num] [-nr] [-rnd] host rnum\n", $progname)
-  STDERR.printf("  %s read [-port num] [-mul num] [-rnd] host rnum\n", $progname)
-  STDERR.printf("  %s remove [-port num] [-rnd] host rnum\n", $progname)
-  STDERR.printf("  %s rcat [-port num] [-shl num] [-dai|-dad] [-ext name] [-xlg|-xlr]" +
-                   " host rnum\n", $progname)
-  STDERR.printf("  %s misc [-port num] host rnum\n", $progname)
-  STDERR.printf("  %s table [-port num] host rnum\n", $progname)
+  STDERR.printf("  %s write [-port num] [-tout num] [-nr] [-rnd] host rnum\n", $progname)
+  STDERR.printf("  %s read [-port num] [-tout num] [-mul num] [-rnd] host rnum\n", $progname)
+  STDERR.printf("  %s remove [-port num] [-tout num] [-rnd] host rnum\n", $progname)
+  STDERR.printf("  %s rcat [-port num] [-tout num] [-shl num] [-dai|-dad] [-ext name]" +
+                " [-xlg|-xlr] host rnum\n", $progname)
+  STDERR.printf("  %s misc [-port num] [-tout num] host rnum\n", $progname)
+  STDERR.printf("  %s table [-port num] [-tout num] host rnum\n", $progname)
   STDERR.printf("\n")
   exit(1)
 end
@@ -72,6 +72,7 @@ def runwrite
   host = nil
   rnum = nil
   port = 1978
+  tout = 0
   nr = false
   rnd = false
   i = 1
@@ -80,6 +81,9 @@ def runwrite
       if ARGV[i] == "-port"
         usage if (i += 1) >= ARGV.length
         port = ARGV[i].to_i
+      elsif ARGV[i] == "-tout"
+        usage if (i += 1) >= ARGV.length
+        tout = ARGV[i].to_i
       elsif ARGV[i] == "-nr"
         nr = true
       elsif ARGV[i] == "-rnd"
@@ -97,7 +101,7 @@ def runwrite
     i += 1
   end
   usage if !host || !rnum || rnum < 1
-  rv = procwrite(host, port, rnum, nr, rnd)
+  rv = procwrite(host, port, tout, rnum, nr, rnd)
   return rv
 end
 
@@ -106,6 +110,7 @@ end
 def runread
   host = nil
   port = 1978
+  tout = 0
   mul = 0
   rnd = false
   i = 1
@@ -114,6 +119,9 @@ def runread
       if ARGV[i] == "-port"
         usage if (i += 1) >= ARGV.length
         port = ARGV[i].to_i
+      elsif ARGV[i] == "-tout"
+        usage if (i += 1) >= ARGV.length
+        tout = ARGV[i].to_i
       elsif ARGV[i] == "-mul"
         usage if (i += 1) >= ARGV.length
         mul = ARGV[i].to_i
@@ -130,7 +138,7 @@ def runread
     i += 1
   end
   usage if !host
-  rv = procread(host, port, mul, rnd)
+  rv = procread(host, port, tout, mul, rnd)
   return rv
 end
 
@@ -139,6 +147,7 @@ end
 def runremove
   host = nil
   port = 1978
+  tout = 0
   rnd = false
   i = 1
   while i < ARGV.length
@@ -146,6 +155,9 @@ def runremove
       if ARGV[i] == "-port"
         usage if (i += 1) >= ARGV.length
         port = ARGV[i].to_i
+      elsif ARGV[i] == "-tout"
+        usage if (i += 1) >= ARGV.length
+        tout = ARGV[i].to_i
       elsif ARGV[i] == "-rnd"
         rnd = true
       else
@@ -159,7 +171,7 @@ def runremove
     i += 1
   end
   usage if !host
-  rv = procremove(host, port, rnd)
+  rv = procremove(host, port, tout, rnd)
   return rv
 end
 
@@ -169,6 +181,7 @@ def runrcat
   host = nil
   rnum = nil
   port = 1978
+  tout = 0
   shl = 0
   dai = false
   dad = false
@@ -180,6 +193,9 @@ def runrcat
       if ARGV[i] == "-port"
         usage if (i += 1) >= ARGV.length
         port = ARGV[i].to_i
+      elsif ARGV[i] == "-tout"
+        usage if (i += 1) >= ARGV.length
+        tout = ARGV[i].to_i
       elsif ARGV[i] == "-shl"
         usage if (i += 1) >= ARGV.length
         shl = ARGV[i].to_i
@@ -207,7 +223,7 @@ def runrcat
     i += 1
   end
   usage if !host || !rnum || rnum < 1
-  rv = procrcat(host, port, rnum, shl, dai, dad, ext, xopts)
+  rv = procrcat(host, port, tout, rnum, shl, dai, dad, ext, xopts)
   return rv
 end
 
@@ -217,12 +233,16 @@ def runmisc
   host = nil
   rnum = nil
   port = 1978
+  tout = 0
   i = 1
   while i < ARGV.length
     if !host && ARGV[i] =~ /^-/
       if ARGV[i] == "-port"
         usage if (i += 1) >= ARGV.length
         port = ARGV[i].to_i
+      elsif ARGV[i] == "-tout"
+        usage if (i += 1) >= ARGV.length
+        tout = ARGV[i].to_i
       else
         usage
       end
@@ -236,7 +256,7 @@ def runmisc
     i += 1
   end
   usage if !host || !rnum || rnum < 1
-  rv = procmisc(host, port, rnum)
+  rv = procmisc(host, port, tout, rnum)
   return rv
 end
 
@@ -246,12 +266,16 @@ def runtable
   host = nil
   rnum = nil
   port = 1978
+  tout = 0
   i = 1
   while i < ARGV.length
     if !host && ARGV[i] =~ /^-/
       if ARGV[i] == "-port"
         usage if (i += 1) >= ARGV.length
         port = ARGV[i].to_i
+      elsif ARGV[i] == "-tout"
+        usage if (i += 1) >= ARGV.length
+        tout = ARGV[i].to_i
       else
         usage
       end
@@ -265,19 +289,19 @@ def runtable
     i += 1
   end
   usage if !host || !rnum || rnum < 1
-  rv = proctable(host, port, rnum)
+  rv = proctable(host, port, tout, rnum)
   return rv
 end
 
 
 # perform write command
-def procwrite(host, port, rnum, nr, rnd)
-  printf("<Writing Test>\n  host=%s  port=%d  rnum=%d  nr=%s  rnd=%s\n\n",
-         host, port, rnum, nr, rnd)
+def procwrite(host, port, tout, rnum, nr, rnd)
+  printf("<Writing Test>\n  host=%s  port=%d  tout=%d  rnum=%d  nr=%s  rnd=%s\n\n",
+         host, port, tout, rnum, nr, rnd)
   err = false
   stime = Time.now
   rdb = RDB::new
-  if !rdb.open(host, port)
+  if !rdb.open(host, port, tout)
     eprint(rdb, "open")
     err = true
   end
@@ -320,12 +344,13 @@ end
 
 
 # perform read command
-def procread(host, port, mul, rnd)
-  printf("<Reading Test>\n  host=%s  port=%d  mul=%d  rnd=%s\n\n", host, port, mul, rnd)
+def procread(host, port, tout, mul, rnd)
+  printf("<Reading Test>\n  host=%s  port=%d  tout=%d  mul=%d  rnd=%s\n\n",
+         host, port, tout, mul, rnd)
   err = false
   stime = Time.now
   rdb = RDB::new
-  if !rdb.open(host, port)
+  if !rdb.open(host, port, tout)
     eprint(rdb, "open")
     err = true
   end
@@ -370,12 +395,13 @@ end
 
 
 # perform remove command
-def procremove(host, port, rnd)
-  printf("<Removing Test>\n  host=%s  port=%d  rnd=%s\n\n", host, port, rnd)
+def procremove(host, port, tout, rnd)
+  printf("<Removing Test>\n  host=%s  port=%d  tout=%d  rnd=%s\n\n",
+         host, port, tout, rnd)
   err = false
   stime = Time.now
   rdb = RDB::new
-  if !rdb.open(host, port)
+  if !rdb.open(host, port, tout)
     eprint(rdb, "open")
     err = true
   end
@@ -407,13 +433,14 @@ end
 
 
 # perform rcat command
-def procrcat(host, port, rnum, shl, dai, dad, ext, xopts)
-  printf("<Random Concatenating Test>\n  host=%s  port=%d  rnum=%d  shl=%d  dai=%s  dad=%s" +
-         "  ext=%s  xopts=%d\n\n", host, port, rnum, shl, dai, dad, ext ? ext : "", xopts)
+def procrcat(host, port, tout, rnum, shl, dai, dad, ext, xopts)
+  printf("<Random Concatenating Test>\n  host=%s  port=%d  tout=%d  rnum=%d" +
+         "  shl=%d  dai=%s  dad=%s  ext=%s  xopts=%d\n\n",
+         host, port, tout, rnum, shl, dai, dad, ext ? ext : "", xopts)
   err = false
   stime = Time.now
   rdb = RDB::new
-  if !rdb.open(host, port)
+  if !rdb.open(host, port, tout)
     eprint(rdb, "open")
     err = true
   end
@@ -474,12 +501,13 @@ end
 
 
 # perform misc command
-def procmisc(host, port, rnum)
-  printf("<Miscellaneous Test>\n  host=%s  port=%d  rnum=%d\n\n", host, port, rnum)
+def procmisc(host, port, tout, rnum)
+  printf("<Miscellaneous Test>\n  host=%s  port=%d  tout=%d  rnum=%d\n\n",
+         host, port, tout, rnum)
   err = false
   stime = Time.now
   rdb = RDB::new
-  if !rdb.open(host, port)
+  if !rdb.open(host, port, tout)
     eprint(rdb, "open")
     err = true
   end
@@ -752,12 +780,13 @@ end
 
 
 # perform table command
-def proctable(host, port, rnum)
-  printf("<Table Extension Test>\n  host=%s  port=%d  rnum=%d\n\n", host, port, rnum)
+def proctable(host, port, tout, rnum)
+  printf("<Table Extension Test>\n  host=%s  port=%d  tout=%d  rnum=%d\n\n",
+         host, port, tout, rnum)
   err = false
   stime = Time.now
   rdb = RDBTBL::new
-  if !rdb.open(host, port)
+  if !rdb.open(host, port, tout)
     eprint(rdb, "open")
     err = true
   end
