@@ -3,15 +3,14 @@
 require 'rbconfig'
 
 commands = [
-
-            "tcrtest.rb write 127.0.0.1 10000",
-            "tcrtest.rb read 127.0.0.1",
-            "tcrtest.rb remove 127.0.0.1",
-            "tcrtest.rb rcat 127.0.0.1 1000",
-            "tcrtest.rb rcat -shl 10 127.0.0.1 1000",
-            "tcrtest.rb rcat -dai 127.0.0.1 1000",
-            "tcrtest.rb rcat -ext put 127.0.0.1 1000",
-            "tcrtest.rb misc 127.0.0.1 1000",
+            "tcrtest.rb write -tout 3 127.0.0.1 10000",
+            "tcrtest.rb read -tout 3 127.0.0.1",
+            "tcrtest.rb remove -tout 3 127.0.0.1",
+            "tcrtest.rb rcat -tout 3 127.0.0.1 1000",
+            "tcrtest.rb rcat -tout 3 -shl 10 127.0.0.1 1000",
+            "tcrtest.rb rcat -tout 3 -dai 127.0.0.1 1000",
+            "tcrtest.rb rcat -tout 3 -ext put 127.0.0.1 1000",
+            "tcrtest.rb misc -tout 3 127.0.0.1 1000",
            ]
 rubycmd = Config::CONFIG["bindir"] + "/" + RbConfig::CONFIG['ruby_install_name']
 num = 1
